pub struct AllocMap<const N: usize>(IntervalBitmap<N>)
where
[(); { _ }]:;Expand description
Allocation map, backed by an interval tree on top of a bitmap.
N must be a power of two. Steps are taken to treat incorrect input (rounded to nearest power).
Tuple Fields
0: IntervalBitmap<N>Implementations
Sourceimpl<const N: usize> AllocMap<N>
impl<const N: usize> AllocMap<N>
Sourcefn find_first_free(&self) -> Option<usize>
fn find_first_free(&self) -> Option<usize>
Returns interval index of first unallocated item, if exists
Sourcepub fn allocate(&mut self) -> Option<usize>
pub fn allocate(&mut self) -> Option<usize>
Allocates the smallest available space and returns its index
Sourcepub fn deallocate(&mut self, index: usize)
pub fn deallocate(&mut self, index: usize)
Deallocates the target index
pub fn is_allocated(&mut self, index: usize) -> bool
pub fn has_free(&self) -> bool